pub fn leave_intent<T: Config>()Expand description
Deregister origin as a collator candidate. Note that the collator can only leave on
session change. The CandidacyBond will start un-bonding process.
This call will fail if the total number of candidates would drop below MinCandidates.
This call is not available to Invulnerable collators.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::leave_intent.