pub fn set_slash_destination<T: Config>(destination: Option<T::AccountId>)Expand description
Set slash destination.
Use Some to deposit slashed balance into destination or None to burn it.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::set_slash_destination.